LiveLog — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# LiveLog

Obtient les données météo, les stocke et les traite.

Exécuter en continu, ayant définit quelles sont les tâches à accomplir.

    usage: python -m pywws.LiveLog [options] data_dir
    options are:
     -h      or --help      display this help
     -l file or --log file  write log information to file
     -v      or --verbose   increase amount of reassuring messages
    data_dir is the root directory of the weather data (e.g. /data/weather)

Pour plus d’informations sur l’utilisation `LiveLog.py`, voir Comment configurer le mode ‘live’ avec pywws.

Fonctions

`LiveLog`(data_dir) |
`main`([argv]) |

`pywws.LiveLog.` `LiveLog`(data_dir)

`pywws.LiveLog.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »